@@ -5,7 +5,7 @@
  *@ TODO With an on_loop_tick_event, trigger cache update once per loop max.
  *@ TODO I.e., unless *netrc-pipe* was set, auto check for updates.
  *
- * Copyright (c) 2014 - 2019 Steffen (Daode) Nurpmeso <steffen@sdaoden.eu>.
+ * Copyright (c) 2014 - 2020 Steffen (Daode) Nurpmeso <steffen@sdaoden.eu>.
  * SPDX-License-Identifier: ISC
  *
  * Permission to use, copy, modify, and/or distribute this software for any
@@ -337,7 +337,7 @@ a_netrc__token(FILE *fi, char buffer[a_NETRC_TOKEN_MAXLEN], boole *nl_last){
             if((c = getc(fi)) == EOF)
                break;
          *cp++ = c;
-         if(PCMP(cp, ==, &buffer[a_NETRC_TOKEN_MAXLEN])){
+         if(PCMP(cp, ==, &buffer[a_NETRC_TOKEN_MAXLEN -1])){
             rv = a_NETRC_ERROR;
             goto jleave;
          }
@@ -349,7 +349,7 @@ a_netrc__token(FILE *fi, char buffer[a_NETRC_TOKEN_MAXLEN], boole *nl_last){
          if(c == '\\' && (c = getc(fi)) == EOF)
                break;
          *cp++ = c;
-         if(PCMP(cp, ==, &buffer[a_NETRC_TOKEN_MAXLEN])){
+         if(PCMP(cp, ==, &buffer[a_NETRC_TOKEN_MAXLEN -1])){
             rv = a_NETRC_ERROR;
             goto jleave;
          }
@@ -434,9 +434,12 @@ a_netrc_dump(char const *cmdname, char const *key, void const *dat){
    }
 
    s = n_string_push_c(s, '\n');
+
    n_string_cp(s);
 
-   slp = R(struct n_strlist*,s->s_dat);
+   slp = R(struct n_strlist*,S(void*,s->s_dat));
+   /* xxx Should we assert alignment constraint of slp is satisfied?
+    * xxx Should be, heap memory with alignment < sizeof(void*) bitter? */
    slp->sl_next = NIL;
    slp->sl_len = s->s_len;
    n_string_drop_ownership(s);
